@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.0.24';
+our $VERSION = '0.0.25';
 
 1;
 
@@ -21,7 +21,7 @@ L<![Build Status](https://travis-ci.org/melezhik/sparrow.svg)|https://travis-ci.
 
 =head1 SYNOPSIS
 
-Sparrow - outthentic plugins manager.  Manages outthentic family suites.
+Sparrow - Multipurposes scenarios manager.
 
 
 =head1 CAVEAT
@@ -388,7 +388,7 @@ There are two ways to run outthentic suites:
 
 First one is to run suite I<via checkpoint interface>:
 
-I<sparrow check run $project_name $check_name> [ -- runtime-parameters ]
+I<sparrow check run $project_name $check_name> [ --options ]
 
 For example:
 
@@ -430,10 +430,18 @@ Only L<public plugins|#public-plugins> could be run using plugin interface.
 
 It is possible to pass I<whatever> runtime parameters when invoke plugin run via checkpoint interface.
 
-    $ sparrow check run system disk -- --param disk.threshold=60
+    $ sparrow check run system disk --param threshold=60
 
-Runtime parameters override default parameters values set in checkpoint configurations, see L<configuring checkpoints|#Configuring-checkpoints>
-later.
+Runtime parameters override default parameters values set in checkpoint configurations, see L<configuring checkpoints|#configuring-checkpoints> section.
+
+
+=head2 Verbosity
+
+To enable verbosity run with `--verbose' option. 
+
+This option makes a sence only for generic suites, follow L<Outthentic documentation|https://github.com/melezhik/outthentic#options> for details.
+
+    $ sparrow check run system disk --verbose
 
 
 =head2 Running suites with cron
